==> beacon_0_1_5.zip: beacon/beacon/language/en_common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of beacon
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


// ITEM PAGE
$lang['hdr_latest_items'] = 				"recent articles";
$lang['hdr_items'] = 						"articles";
$lang['href_list'] = 						"full list";
$lang['href_print'] = 						"print version";
$lang['href_edit_this'] = 					"Edit this";

// COMMON
$lang['txt_page_title'] = 					"Beacon";
$lang['txt_logoff'] = 						"log off";
$lang['txt_last_edited'] = 					"last edited";
$lang['txt_created'] = 						"created";
$lang['txt_strap'] = 						"This <a href=\"http://www.fsf.org/\">free software</a> is created and maintained by <a href=\"http://www.barnraiser.org/\">Barnraiser</a>. We are dedicated to giving people the tools they need to share knowledge and further society through social software. Please consider <a href='http://www.barnraiser.org/contribute/'>supporting us</a>.";
$lang['txt_comment_leave_help'] = 			"Please note: You need to login to leave a comment.";

$lang['hdr_links'] = 						"links";
$lang['hdr_menu'] = 						"menu";

$lang['href_login_register'] = 				"login or register";
$lang['href_account'] = 					"account";
$lang['href_edit_menu'] = 					"Edit menus";
$lang['href_edit_items'] = 					"Edit articles";
$lang['href_edit_files'] = 					"Edit files";
$lang['href_edit_categories'] = 			"Edit categories";
$lang['href_edit_contributors'] = 			"Edit contributors";
$lang['href_send_newsletter'] = 			"Send newsletter";
$lang['href_search'] = 						"search";


//METADATA
$lang['meta_keywords'] =					""; //add in a description for your node
$lang['meta_Description'] = 				""; //add in up to 25 keywords (barnraiser, beacon, etc)
$lang['meta_OriginalPublicationDate'] =		"2005/05/31";//YYYY/MM/DD // //add in a publication date


//PRINT ITEM TEXT
$lang['txt_copyright'] = 					"All content under this domain is deemed to be free content under the <a href='http://www.gnu.org/copyleft/fdl.html'>GNU Free Documentation License</a> (GFDL), meaning that it may be freely used, freely edited, freely copied and freely redistributed subject to the restrictions of that license.";
$lang['txt_copyright_print'] = 				"All content under this domain is deemed to be free content under the GNU Free Documentation License (GFDL - <a href='http://www.gnu.org/copyleft/fdl.html'>http://www.gnu.org/copyleft/fdl.html</a>), meaning that it may be freely used, freely edited, freely copied and freely redistributed subject to the restrictions of that license.";
$lang['txt_source'] =						"Source";


//RSS
$lang['txt_title'] = 						"this_site.org blog";
$lang['txt_description'] = 					"A blog from this_site.";
$lang['txt_image_title'] = 					"RSS version 2.0 feed";


// LANGUAGE
$lang['language'][1] = 						"English";


// ERRORS
$lang['arr_error'][1] =						"Database error.";
$lang['arr_error'][2] = 					"This file needs to jpg,gif,png,txt or pdf format.";
$lang['arr_error'][3] = 					"You have not entered a title.";
$lang['arr_error'][4] =						"Your email address or password incorrect.";
$lang['arr_error'][5] =						"Your email is not registered with us. Please register to continue or try another email.";
$lang['arr_error'][6] =						"Your password needs to be more than 5 characters long";
$lang['arr_error'][7] =						"Thank you for registering with us. You will receive an email from us. Just follow the instructions in it to complete registration with us.";
$lang['arr_error'][8] =						"Your captcha word does not work. Please try again.";
$lang['arr_error'][9] =						"Each article requires a wikipage name so that you can link to it from another article. Please add a wikipage name. It should be at least 5 characters long and be in StudlyCapsFromat.";
$lang['arr_error'][10] =					"You have not entered any body text.";
$lang['arr_error'][11] =					"Sorry, your chosen wiki page name has already been taken. Please choose another name.";
$lang['arr_error'][12] = 					"Please use three or more characters when performing a search.";
$lang['arr_error'][13] = 					"Warning! This is not the newest version of this article. <a href=\"index.php?page=WIKIPAGE\">The newest version is available here</a>.";
$lang['arr_error'][14] =					"A new password has been sent to you. If you continue to have problems email us at support@your_domain.com";
$lang['arr_error'][15] =					"Please fill all the fields in.";
$lang['arr_error'][16] =					"Mail error.";
$lang['arr_error'][17] =					"Your account has been updated. If you have changed your password, you will need to use that when you next log in.";
$lang['arr_error'][18] =					"Thank you. You have completed registration with us. Login to continue!";
$lang['arr_error'][19] =					"There was a problem with your registration. Please email support@your_domain.com for more information.";
$lang['arr_error'][20] =					"NUMBER messages were sent with your newsletter."; // do not translate NUMBER

// EMAIL PARSER
$lang['email']['dot'] = 					"dot";
$lang['email']['at'] = 						"at";

//COMMENTS
$lang['hdr_comments'] = 					"comments";
$lang['err_no_comments'] = 					"This article has no comments.";
$lang['hdr_comment_preview'] = 				"preview of your comment";
$lang['hdr_add_comment'] = 					"add a comment to this article";
$lang['txt_comment_help'] = 				"Please read the <a href='index.php?page=SitePolicy'>site policy</a> guide before posting. Any comments that do not comply with this guide will be removed without prior author approval.";
$lang['txt_email_withheld'] = 				"email withheld";

$lang['href_item_comments_only'] = 			"Show only the comment against this version of this page";
$lang['href_all_comments'] = 				"Show all comments associated with this page";

$lang['form_submit_preview'] = 				"PREVIEW";
$lang['form_submit_add'] = 					"ADD";
$lang['form_submit_spelling'] = 			"SPELL CHECK";
$lang['form_submit_save'] = 				"SAVE";
$lang['form_submit_edit_again'] = 			"EDIT AGAIN";
?>

==> beacon_0_1_6.zip: beacon/beacon/language/en_common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of beacon
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


// ITEM PAGE
$lang['hdr_latest_items'] = 				"recent articles";
$lang['hdr_items'] = 						"articles";
$lang['href_list'] = 						"full list";
$lang['href_print'] = 						"print version";
$lang['href_edit_this'] = 					"Edit this";

// COMMON
$lang['txt_page_title'] = 					"Beacon";
$lang['txt_logoff'] = 						"log off";
$lang['txt_last_edited'] = 					"last edited";
$lang['txt_created'] = 						"created";
$lang['txt_strap'] = 						"This <a href=\"http://www.fsf.org/\">free software</a> is created and maintained by <a href=\"http://www.barnraiser.org/\">Barnraiser</a>. We are dedicated to giving people the tools they need to share knowledge and further society through social software. Please consider <a href='http://www.barnraiser.org/contribute/'>supporting us</a>.";
$lang['txt_comment_leave_help'] = 			"Please note: You need to login to leave a comment.";

$lang['hdr_links'] = 						"links";
$lang['hdr_menu'] = 						"menu";

$lang['href_login_register'] = 				"login or register";
$lang['href_account'] = 					"account";
$lang['href_edit_menu'] = 					"Edit menus";
$lang['href_edit_items'] = 					"Edit articles";
$lang['href_edit_files'] = 					"Edit files";
$lang['href_edit_categories'] = 			"Edit categories";
$lang['href_edit_contributors'] = 			"Edit contributors";
$lang['href_send_newsletter'] = 			"Send newsletter";
$lang['href_search'] = 						"search";


//METADATA
$lang['meta_keywords'] =					""; //add in a description for your node
$lang['meta_Description'] = 				""; //add in up to 25 keywords (barnraiser, beacon, etc)
$lang['meta_OriginalPublicationDate'] =		"2005/05/31";//YYYY/MM/DD // //add in a publication date


//PRINT ITEM TEXT
$lang['txt_copyright'] = 					"All content under this domain is deemed to be free content under the <a href='http://www.gnu.org/copyleft/fdl.html'>GNU Free Documentation License</a> (GFDL), meaning that it may be freely used, freely edited, freely copied and freely redistributed subject to the restrictions of that license.";
$lang['txt_copyright_print'] = 				"All content under this domain is deemed to be free content under the GNU Free Documentation License (GFDL - <a href='http://www.gnu.org/copyleft/fdl.html'>http://www.gnu.org/copyleft/fdl.html</a>), meaning that it may be freely used, freely edited, freely copied and freely redistributed subject to the restrictions of that license.";
$lang['txt_source'] =						"Source";


//RSS
$lang['txt_title'] = 						"this_site.org blog";
$lang['txt_description'] = 					"A blog from this_site.org";
$lang['txt_image_title'] = 					"Beacon";
$lang['txt_author'] = 						"Beacon";


// LANGUAGE
$lang['language'][1] = 						"English";


// ERRORS
$lang['arr_error'][1] =						"Database error.";
$lang['arr_error'][2] = 					"This file needs to jpg,gif,png,txt or pdf format.";
$lang['arr_error'][3] = 					"You have not entered a title.";
$lang['arr_error'][4] =						"Your email address or password incorrect.";
$lang['arr_error'][5] =						"Your email is not registered with us. Please register to continue or try another email.";
$lang['arr_error'][6] =						"Your password needs to be more than 5 characters long";
$lang['arr_error'][7] =						"Thank you for registering with us. You will receive an email from us. Just follow the instructions in it to complete registration with us.";
$lang['arr_error'][8] =						"Your captcha word does not work. Please try again.";
$lang['arr_error'][9] =						"Each article requires a wikipage name so that you can link to it from another article. Please add a wikipage name. It should be at least 5 characters long and be in StudlyCapsFromat.";
$lang['arr_error'][10] =					"You have not entered any body text.";
$lang['arr_error'][11] =					"Sorry, your chosen wiki page name has already been taken. Please choose another name.";
$lang['arr_error'][12] = 					"Please use three or more characters when performing a search.";
$lang['arr_error'][13] = 					"Warning! This is not the newest version of this article. <a href=\"index.php?page=WIKIPAGE\">The newest version is available here</a>.";
$lang['arr_error'][14] =					"A new password has been sent to you. If you continue to have problems email us at support@your_domain.com";
$lang['arr_error'][15] =					"Please fill all the fields in.";
$lang['arr_error'][16] =					"Mail error.";
$lang['arr_error'][17] =					"Your account has been updated. If you have changed your password, you will need to use that when you next log in.";
$lang['arr_error'][18] =					"Thank you. You have completed registration with us. Login to continue!";
$lang['arr_error'][19] =					"There was a problem with your registration. Please email support@your_domain.com for more information.";
$lang['arr_error'][20] =					"NUMBER messages were sent with your newsletter."; // do not translate NUMBER

// EMAIL PARSER
$lang['email']['dot'] = 					"dot";
$lang['email']['at'] = 						"at";

//COMMENTS
$lang['hdr_comments'] = 					"comments";
$lang['err_no_comments'] = 					"This article has no comments.";
$lang['hdr_comment_preview'] = 				"preview of your comment";
$lang['hdr_add_comment'] = 					"add a comment to this article";
$lang['txt_comment_help'] = 				"Please read the <a href='index.php?page=SitePolicy'>site policy</a> guide before posting. Any comments that do not comply with this guide will be removed without prior author approval.";
$lang['txt_email_withheld'] = 				"email withheld";

$lang['href_item_comments_only'] = 			"Show only the comment against this version of this page";
$lang['href_all_comments'] = 				"Show all comments associated with this page";

$lang['form_submit_preview'] = 				"PREVIEW";
$lang['form_submit_add'] = 					"ADD";
$lang['form_submit_spelling'] = 			"SPELL CHECK";
$lang['form_submit_save'] = 				"SAVE";
$lang['form_submit_edit_again'] = 			"EDIT AGAIN";
?>
